@@ -88,6 +88,8 @@ from sarpy.io.DEM.DTED import DTEDList, DTEDInterpolator
 
 logger = logging.getLogger(__name__)
 
+_unhandled_text = 'Got unhandled type `{}`'
+_unsupported_text = 'Got unsupported projection type `{}`'
 
 #############
 # COA Projection definition
@@ -325,7 +327,7 @@ def _get_sicd_type_specific_projection(sicd):
     else:
         # NB: this will have been noted by sicd.can_project_coordinates(), but is
         #   here for completeness
-        raise ValueError('Unhandled Grid.Type'.format(sicd.Grid.Type))
+        raise ValueError('Unhandled Grid.Type `{}`'.format(sicd.Grid.Type))
 
 
 def _get_sicd_adjustment_params(sicd, delta_arp, delta_varp, adj_params_frame):
@@ -422,7 +424,7 @@ def _get_sidd_type_projection(sidd):
         return plane_proj.TimeCOAPoly, method_projection
 
     if not isinstance(sidd, (SIDDType2, SIDDType1)):
-        raise TypeError('Got unhandled type {}'.format(type(sidd)))
+        raise TypeError(_unhandled_text.format(type(sidd)))
 
     if sidd.Measurement.PlaneProjection is not None:
         return pgp(sidd)
@@ -692,7 +694,7 @@ def _get_coa_projection(structure, use_structure_coa, **coa_args):
     elif isinstance(structure, (SIDDType2, SIDDType1)):
         return COAProjection.from_sidd(structure, **coa_args)
     else:
-        raise ValueError('Got unhandled type {}'.format(type(structure)))
+        raise ValueError(_unhandled_text.format(type(structure)))
 
 
 ###############
@@ -720,10 +722,10 @@ def _get_reference_point(structure):
     elif isinstance(structure, (SIDDType2, SIDDType1)):
         proj_type = structure.Measurement.ProjectionType
         if proj_type != 'PlaneProjection':
-            raise ValueError('Got unsupported projection type {}'.format(proj_type))
+            raise ValueError(_unsupported_text.format(proj_type))
         return structure.Measurement.PlaneProjection.ReferencePoint.ECEF.get_array(dtype='float64')
     else:
-        raise TypeError('Got unhandled type {}'.format(type(structure)))
+        raise TypeError(_unhandled_text.format(type(structure)))
 
 
 def _get_outward_norm(structure, gref):
@@ -751,7 +753,7 @@ def _get_outward_norm(structure, gref):
     elif isinstance(structure, (SIDDType2, SIDDType1)):
         proj_type = structure.Measurement.ProjectionType
         if proj_type != 'PlaneProjection':
-            raise ValueError('Got unsupported projection type {}'.format(proj_type))
+            raise ValueError(_unsupported_text.format(proj_type))
         the_proj = structure.Measurement.PlaneProjection
         # image plane details
         uRow = the_proj.ProductPlane.RowUnitVector.get_array(dtype='float64')
@@ -763,7 +765,7 @@ def _get_outward_norm(structure, gref):
             uGPN *= -1
         return uGPN
     else:
-        raise TypeError('Got unhandled type {}'.format(type(structure)))
+        raise TypeError(_unhandled_text.format(type(structure)))
 
 
 def _extract_plane_params(structure):
@@ -811,7 +813,7 @@ def _extract_plane_params(structure):
     elif isinstance(structure, (SIDDType1, SIDDType2)):
         proj_type = structure.Measurement.ProjectionType
         if proj_type != 'PlaneProjection':
-            raise ValueError('Got unsupported projection type {}'.format(proj_type))
+            raise ValueError(_unsupported_text.format(proj_type))
 
         the_proj = structure.Measurement.PlaneProjection
 
